# NetbiosSpoof

## Description
This package implement a Netbios Spoofer (Netbios, LLMNR, DNS Local).

## Requirements
This package require :
 - python3
 - python3 Standard Library
 - Scapy

## Installation
```bash
pip install NetbiosSpoof
```

## Examples

### Command lines
```bash
NetbiosSpoof
```

### Python3
```python
from NetbiosSpoof import NetbiosSpoof
NetbiosSpoof().launch()
```

## Link
[Github Page](https://github.com/mauricelambert/NetbiosSpoof)

## Licence
Licensed under the [GPL, version 3](https://www.gnu.org/licenses/).